@@ -144,7 +144,23 @@ mod tests {
         parse_quote!(
             #[builder]
             impl Foo {
-                fn new<K: Into<String>, V: Into<String>>(param: HashMap<K, V>) -> Foo {
+                fn new<K: Into<String> + Eq + Hash, V: Into<String>>(param: HashMap<K, V>) -> Foo {
+                    Self {
+                        param: param
+                            .into_iter()
+                            .map(|(k, v)| (k.into(), v.into()))
+                            .collect(),
+                    }
+                }
+            }
+        )
+    }
+
+    pub fn collections_option_test_case() -> Ast {
+        parse_quote!(
+            #[builder]
+            impl Foo {
+                fn new(param: HashMap<Option<String>, Option<String>>) -> Foo {
                     Self {
                         param: param
                             .into_iter()
